==> nocc-1.9.5.txz: usr/local/www/nocc/lang/nl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: nl.php 2621 2014-06-23 12:43:39Z siebrand $
 */
/** Dutch (Nederlands)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Mathijs Kolenberg <mack@solcon.nl>
 * @author McDutchie
 * @author Pieterjan Goppel <lp_leeki@euronet.nl>
 * @author SPQRobin
 * @author Sander Schroevers
 * @author Siebrand
 * @author Silvan Jongerius <sjongerius@duxy.nl>
 * @author Southparkfan
 * @author openfan <leprincevelours@yahoo.com>
 */

$lang_locale = 'nl_NL.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Het veld voor uw gebruikersnaam is nog leeg';
$err_passwd_empty = 'Het wachtwoordveld is nog leeg';
$alt_delete = 'Geselecteerde berichten verwijderen';
$alt_delete_one = 'Bericht verwijderen';
$alt_new_msg = 'Nieuwe berichten';
$alt_reply = 'Afzender beantwoorden';
$alt_reply_all = 'Allen beantwoorden';
$alt_forward = 'Doorsturen';
$alt_next = 'Volgende';
$alt_prev = 'Vorige';
$title_next_page = 'Volgende pagina';
$title_prev_page = 'Vorige pagina';
$title_next_msg = 'Volgend bericht';
$title_prev_msg = 'Vorig bericht';
$html_theme_label = 'Weergave:';
$html_welcome = 'Welkom bij %1$s';
$html_login = 'Aanmelden';
$html_user_label = 'Gebruiker:';
$html_passwd_label = 'Wachtwoord:';
$html_submit = 'Verzenden';
$html_help = 'Hulp';
$html_server_label = 'Server:';
$html_wrong = 'De gebruikersnaam of het wachtwoord is onjuist';
$html_retry = 'Opnieuw proberen';
$html_remember = 'Instellingen onthouden';
$html_lang_label = 'Taal:';
$html_msgperpage_label = 'Aantal berichten per pagina:';
$html_preferences = 'Voorkeuren';
$html_full_name_label = 'Volledige naam:';
$html_email_address_label = 'E-mailadres:';
$html_bccself = 'Bcc naar eigen e-mailadres';
$html_hide_addresses = 'E-mailadressen verbergen';
$html_outlook_quoting = 'Oorspronkelijk bericht in Outlookstijl aanhalen';
$html_reply_to = 'Antwoorden naar';
$html_reply_to_label = 'Antwoorden naar:';
$html_use_signature = 'Handtekening gebruiken';
$html_signature = 'Handtekening';
$html_signature_label = 'Handtekening:';
$html_reply_leadin_label = 'Tekst bij antwoorden:';
$html_prefs_updated = 'Uw instellingen zijn opgeslagen';
$html_manage_folders_link = 'IMAP-mappen beheren';
$html_manage_filters_link = 'E-mailfilters beheren';
$html_use_graphical_smilies = 'Grafische smiley\'s gebruiken';
$html_sent_folder_label = 'Verzonden berichten naar eigen map kopiëren:';
$html_trash_folder_label = 'Verwijderde berichten naar eigen map verplaatsen:';
$html_colored_quotes = 'Gekleurd aanhalen';
$html_display_struct = 'Gestructureerde tekst weergeven';
$html_send_html_mail = 'Berichten in HTML-opmaak verzenden';
$html_folders = 'Mappen';
$html_folders_create_failed = 'De map kon niet worden aangemaakt!';
$html_folders_sub_failed = 'Het abonneren op de map is mislukt!';
$html_folders_unsub_failed = 'Het verwijderen van het abonnement op de map is mislukt!';
$html_folders_rename_failed = 'De map kon niet worden hernoemd!';
$html_folders_updated = 'De mappen zijn bijgewerkt';
$html_folder_subscribe = 'Abonneren op map:';
$html_folder_rename = 'Hernoemen';
$html_folder_create = 'Nieuwe map maken met naam:';
$html_folder_remove = 'Niet meer abonneren op map:';
$html_folder_delete = 'Verwijderen';
$html_folder_to = 'naar:';
$html_filter_remove = 'Verwijderen';
$html_filter_body = 'Berichtinhoud';
$html_filter_subject = 'Onderwerp';
$html_filter_to = 'Aan';
$html_filter_cc = 'Cc';
$html_filter_from = 'Van';
$html_filter_change_tip = 'Wijzig een filter door deze eenvoudigweg te overschrijven.';
$html_reapply_filters = 'Filters opnieuw toepassen';
$html_filter_contains = 'bevat:';
$html_filter_name = 'Filternaam';
$html_filter_action = 'Filteractie';
$html_filter_moveto = 'Verplaatsen naar';
$html_select_one = '-- Selecteer --';
$html_and = 'En';
$html_new_msg_in = 'Nieuwe berichten in';
$html_or = 'of';
$html_move = 'Verplaatsen';
$html_copy = 'Kopiëren';
$html_messages_to = 'geselecteerde berichten aan';
$html_gotopage = 'Ga naar pagina';
$html_gotofolder = 'Ga naar map';
$html_other_folders = 'Mappenlijst';
$html_page = 'Pagina';
$html_of = 'van';
$html_view_header = 'Berichtkoppen weergeven';
$html_remove_header = 'Berichtkoppen verbergen';
$html_inbox = 'Postvak IN';
$html_new_msg = 'Nieuw bericht';
$html_reply = 'Antwoorden';
$html_reply_short = 'Antw:';
$html_reply_all = 'Allen beantwoorden';
$html_forward = 'Doorsturen';
$html_forward_short = 'FW:';
$html_forward_info = 'Het doorgezonden bericht wordt als bijlage van dit bericht verstuurd.';
$html_delete = 'Verwijderen';
$html_new = 'Nieuw';
$html_mark = 'Verwijderen';
$html_att_label = 'Bijlage:';
$html_atts_label = 'Bijlagen:';
$html_unknown = '[onbekend]';
$html_part_x = 'Deel %s';
$html_attach = 'Toevoegen';
$html_attach_forget = 'De bijlage moet nog toegevoegd worden voor verzending!';
$html_attach_delete = 'Selectie verwijderen';
$html_attach_none = 'Selecteer eerst een bestand als bijlage!';
$html_sort_by = 'Sorteren op';
$html_sort = 'Sorteren';
$html_from = 'Van';
$html_from_label = 'Van:';
$html_subject = 'Onderwerp';
$html_subject_label = 'Onderwerp:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Verzonden:';
$html_wrote = 'schreef';
$html_quote_wrote = 'Op %1$s %2$s heeft %3$s geschreven:';
$html_size = 'Grootte';
$html_totalsize = 'Totale grootte';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Bestandsnaam';
$html_to = 'Aan';
$html_to_label = 'Aan:';
$html_cc = 'Cc';
$html_cc_label = 'CC:';
$html_bcc_label = 'BCC:';
$html_nosubject = 'Geen onderwerp';
$html_send = 'Verzenden';
$html_cancel = 'Annuleren';
$html_no_mail = 'Geen berichten.';
$html_logout = 'Afmelden';
$html_msg = 'Bericht';
$html_msgs = 'Berichten';
$html_configuration = 'Deze server is niet goed ingesteld.';
$html_priority = 'Prioriteit';
$html_priority_label = 'Prioriteit:';
$html_lowest = 'Laagste';
$html_low = 'Laag';
$html_normal = 'Normaal';
$html_high = 'Hoog';
$html_highest = 'Hoogste';
$html_flagged = 'Gemarkeerd';
$html_spam = 'Spam';
$html_spam_warning = 'Dit bericht is ingedeeld als spam.';
$html_receipt = 'Ontvangstbevestiging';
$html_select = 'Selecteren';
$html_select_all = 'Selectie omdraaien';
$html_select_contacts = 'Contactpersonen selecteren';
$html_loading_image = 'Afbeelding laden';
$html_send_confirmed = 'Het bericht is verzonden';
$html_no_sendaction = 'Er is geen handeling aangegeven. Zet eventueel JavaScript aan.';
$html_error_occurred = 'Er is een fout opgetreden';
$html_prefs_file_error = 'Het instellingenbestand kan niet worden geopend voor schrijven.';
$html_wrap = 'Aantal karakters voor terugloop voor uitgaande berichten:';
$html_wrap_none = 'Geen terugloop';
$html_usenet_separator = 'Scheidingslijn ("-- \n") voor handtekening gebruiken';
$html_mark_as = 'Markeren als';
$html_read = 'gelezen';
$html_unread = 'ongelezen';
$html_encoding_label = 'Karaktercodering:';
$html_add = 'Toevoegen';
$html_contacts = '%1$s contactpersonen';
$html_modify = 'Wijzigen';
$html_back = 'Terug';
$html_contact_add = 'Nieuw contactpersoon toevoegen';
$html_contact_mod = 'Contactpersoon wijzigen';
$html_contact_first = 'Voornaam';
$html_contact_last = 'Achternaam';
$html_contact_nick = 'Bijnaam';
$html_contact_mail = 'E-mailadres';
$html_contact_list = 'Contactenlijst van %1$s';
$html_contact_del = 'van de contactenlijst';
$html_contact_count = '%1$d contacten';
$html_contact_err1 = 'Het maximaal aantal contactpersonen is "%1$d"';
$html_contact_err2 = 'Er kan geen nieuw contactpersoon toegevoegd worden';
$html_contact_err3 = 'Geen toegang tot de contactenlijst';
$html_contact_none = 'Er zijn nog geen contactpersonen ingesteld.';
$html_del_msg = 'Geselecteerde berichten verwijderen?';
$html_down_mail = 'Downloaden';
$original_msg = '-- Oorspronkelijk bericht --';
$to_empty = 'Het veld \'Aan\' mag niet leeg zijn!';
$html_images_warning = 'Voor uw veiligheid worden afbeeldingen niet weergegeven.';
$html_images_display = 'Afbeeldingen weergeven';
$html_smtp_error_no_conn = 'Het is niet mogelijk een SMTP-verbinding te openen';
$html_smtp_error_unexpected = 'Onverwacht SMTP-antwoord:';
$lang_could_not_connect = 'Er kan geen verbinding gemaakt worden met de server';
$lang_invalid_msg_num = 'Ongeldig berichtnummer';
$html_file_upload_attack = 'Mogelijk illegale poging om bestand te uploaden';
$html_invalid_email_address = 'Ongeldig e-mailadres';
$html_invalid_msg_per_page = 'Ongeldig aantal berichten per pagina';
$html_invalid_wrap_msg = 'Ongeldige terugloopbreedte van het bericht';
$html_seperate_msg_win = 'Berichten in nieuw venster weergeven';
$html_err_file_contacts = 'Er kan niet naar de contactenlijst geschreven worden.';
$html_session_file_error = 'Er kan niet naar het sessiebestand geschreven worden.';
$html_login_not_allowed = 'Deze gebruiker mag geen verbinding maken.';
$lang_err_send_delay = 'Tussen twee e-mails moet u minstens %1$d seconden wachten';
$html_search = 'Zoeken';
$html_new_session = 'Volgende sessie';
$html_fd_filename = '%1$s downloaden';
$html_fd_mailcount = 'Er {{PLURAL:$1|0=staan geen e-mails|1=is %1$d e-mail|staan %1$d e-mails}} in de map.';
$html_fd_mailskip = 'De volgende e-mails worden niet opgenomen in het bestand mbox, omdat ze de PHP-instelling "memory_limit" overschrijden:';
$html_fd_filesize = 'grootte %1$d';
$html_fd_skipcount = 'met %1$d e-mails';
$html_fd_largefolder = 'Afhankelijk van uw downloadsnelheid, is het mogelijk dat het downloaden te lang duurt en wordt afgebroken.<br />Controleer of uw download compleet is of steil de PHP-instelling "max_execution_time" in php.ini hoger in.';
$reset_clicked = 'Weet u zeker dat u deze dit formulieren wilt wissen?';
$html_send_recover = 'Log in om het klad te herstellen!';
$html_send_discard = 'Klik hier om het klad te verwijderen.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/nl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: nl.php 2662 2016-03-09 12:43:49Z siebrand $
 */
/** Dutch (Nederlands)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Mathijs Kolenberg <mack@solcon.nl>
 * @author McDutchie
 * @author Pieterjan Goppel <lp_leeki@euronet.nl>
 * @author SPQRobin
 * @author Sander Schroevers
 * @author Siebrand
 * @author Silvan Jongerius <sjongerius@duxy.nl>
 * @author Southparkfan
 * @author openfan <leprincevelours@yahoo.com>
 */

$lang_locale = 'nl_NL.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Het veld voor uw gebruikersnaam is nog leeg';
$err_passwd_empty = 'Het wachtwoordveld is nog leeg';
$alt_delete = 'Geselecteerde berichten verwijderen';
$alt_delete_one = 'Bericht verwijderen';
$alt_new_msg = 'Nieuwe berichten';
$alt_reply = 'Afzender beantwoorden';
$alt_reply_all = 'Allen beantwoorden';
$alt_forward = 'Doorsturen';
$alt_next = 'Volgende';
$alt_prev = 'Vorige';
$title_next_page = 'Volgende pagina';
$title_prev_page = 'Vorige pagina';
$title_next_msg = 'Volgend bericht';
$title_prev_msg = 'Vorig bericht';
$html_theme_label = 'Weergave:';
$html_welcome = 'Welkom bij %1$s';
$html_login = 'Aanmelden';
$html_user_label = 'Gebruiker:';
$html_passwd_label = 'Wachtwoord:';
$html_submit = 'Verzenden';
$html_help = 'Hulp';
$html_server_label = 'Server:';
$html_wrong = 'De gebruikersnaam of het wachtwoord is onjuist';
$html_retry = 'Opnieuw proberen';
$html_remember = 'Instellingen onthouden';
$html_lang_label = 'Taal:';
$html_msgperpage_label = 'Aantal berichten per pagina:';
$html_preferences = 'Voorkeuren';
$html_full_name_label = 'Volledige naam:';
$html_email_address_label = 'E-mailadres:';
$html_bccself = 'Bcc naar eigen e-mailadres';
$html_hide_addresses = 'E-mailadressen verbergen';
$html_outlook_quoting = 'Oorspronkelijk bericht in Outlookstijl aanhalen';
$html_reply_to = 'Antwoorden naar';
$html_reply_to_label = 'Antwoorden naar:';
$html_use_signature = 'Handtekening gebruiken';
$html_signature = 'Handtekening';
$html_signature_label = 'Handtekening:';
$html_reply_leadin_label = 'Tekst bij antwoorden:';
$html_prefs_updated = 'Uw instellingen zijn opgeslagen';
$html_manage_folders_link = 'IMAP-mappen beheren';
$html_manage_filters_link = 'E-mailfilters beheren';
$html_use_graphical_smilies = 'Grafische smiley\'s gebruiken';
$html_sent_folder_label = 'Verzonden berichten naar eigen map kopiëren:';
$html_trash_folder_label = 'Verwijderde berichten naar eigen map verplaatsen:';
$html_colored_quotes = 'Gekleurd aanhalen';
$html_display_struct = 'Gestructureerde tekst weergeven';
$html_send_html_mail = 'Berichten in HTML-opmaak verzenden';
$html_folders = 'Mappen';
$html_folders_create_failed = 'De map kon niet worden aangemaakt!';
$html_folders_sub_failed = 'Het abonneren op de map is mislukt!';
$html_folders_unsub_failed = 'Het verwijderen van het abonnement op de map is mislukt!';
$html_folders_rename_failed = 'De map kon niet worden hernoemd!';
$html_folders_updated = 'De mappen zijn bijgewerkt';
$html_folder_subscribe = 'Abonneren op map:';
$html_folder_rename = 'Hernoemen';
$html_folder_create = 'Nieuwe map maken met naam:';
$html_folder_remove = 'Niet meer abonneren op map:';
$html_folder_delete = 'Verwijderen';
$html_folder_to = 'naar:';
$html_filter_remove = 'Verwijderen';
$html_filter_body = 'Berichtinhoud';
$html_filter_subject = 'Onderwerp';
$html_filter_to = 'Aan';
$html_filter_cc = 'Cc';
$html_filter_from = 'Van';
$html_filter_change_tip = 'Wijzig een filter door deze eenvoudigweg te overschrijven.';
$html_reapply_filters = 'Filters opnieuw toepassen';
$html_filter_contains = 'bevat:';
$html_filter_name = 'Filternaam';
$html_filter_action = 'Filteractie';
$html_filter_moveto = 'Verplaatsen naar';
$html_select_one = '-- Selecteer --';
$html_and = 'En';
$html_new_msg_in = 'Nieuwe berichten in';
$html_or = 'of';
$html_move = 'Verplaatsen';
$html_copy = 'Kopiëren';
$html_messages_to = 'geselecteerde berichten aan';
$html_gotopage = 'Ga naar pagina';
$html_gotofolder = 'Ga naar map';
$html_other_folders = 'Mappenlijst';
$html_page = 'Pagina';
$html_of = 'van';
$html_view_header = 'Berichtkoppen weergeven';
$html_remove_header = 'Berichtkoppen verbergen';
$html_inbox = 'Postvak IN';
$html_new_msg = 'Nieuw bericht';
$html_reply = 'Antwoorden';
$html_reply_short = 'Antw:';
$html_reply_all = 'Allen beantwoorden';
$html_forward = 'Doorsturen';
$html_forward_short = 'FW:';
$html_forward_info = 'Het doorgezonden bericht wordt als bijlage van dit bericht verstuurd.';
$html_delete = 'Verwijderen';
$html_new = 'Nieuw';
$html_mark = 'Verwijderen';
$html_att_label = 'Bijlage:';
$html_atts_label = 'Bijlagen:';
$html_unknown = '[onbekend]';
$html_part_x = 'Deel %s';
$html_attach = 'Toevoegen';
$html_attach_forget = 'De bijlage moet nog toegevoegd worden voor verzending!';
$html_attach_delete = 'Selectie verwijderen';
$html_attach_none = 'Selecteer eerst een bestand als bijlage!';
$html_sort_by = 'Sorteren op';
$html_sort = 'Sorteren';
$html_from = 'Van';
$html_from_label = 'Van:';
$html_subject = 'Onderwerp';
$html_subject_label = 'Onderwerp:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Verzonden:';
$html_wrote = 'schreef';
$html_quote_wrote = 'Op %1$s %2$s heeft %3$s geschreven:';
$html_size = 'Grootte';
$html_totalsize = 'Totale grootte';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Bestandsnaam';
$html_to = 'Aan';
$html_to_label = 'Aan:';
$html_cc = 'Cc';
$html_cc_label = 'CC:';
$html_bcc_label = 'BCC:';
$html_nosubject = 'Geen onderwerp';
$html_send = 'Verzenden';
$html_cancel = 'Annuleren';
$html_no_mail = 'Geen berichten.';
$html_logout = 'Afmelden';
$html_msg = 'Bericht';
$html_msgs = 'Berichten';
$html_configuration = 'Deze server is niet goed ingesteld.';
$html_priority = 'Prioriteit';
$html_priority_label = 'Prioriteit:';
$html_lowest = 'Laagste';
$html_low = 'Laag';
$html_normal = 'Normaal';
$html_high = 'Hoog';
$html_highest = 'Hoogste';
$html_flagged = 'Gemarkeerd';
$html_spam = 'Spam';
$html_spam_warning = 'Dit bericht is ingedeeld als spam.';
$html_receipt = 'Ontvangstbevestiging';
$html_select = 'Selecteren';
$html_select_all = 'Selectie omdraaien';
$html_select_contacts = 'Contactpersonen selecteren';
$html_loading_image = 'Afbeelding laden';
$html_send_confirmed = 'Het bericht is verzonden';
$html_no_sendaction = 'Er is geen handeling aangegeven. Zet eventueel JavaScript aan.';
$html_error_occurred = 'Er is een fout opgetreden';
$html_prefs_file_error = 'Het instellingenbestand kan niet worden geopend voor schrijven.';
$html_wrap = 'Aantal tekens voor terugloop voor uitgaande berichten:';
$html_wrap_none = 'Geen terugloop';
$html_usenet_separator = 'Scheidingslijn ("-- \n") voor handtekening gebruiken';
$html_mark_as = 'Markeren als';
$html_read = 'gelezen';
$html_unread = 'ongelezen';
$html_encoding_label = 'Karaktercodering:';
$html_add = 'Toevoegen';
$html_contacts = '%1$s contactpersonen';
$html_modify = 'Wijzigen';
$html_back = 'Terug';
$html_contact_add = 'Nieuw contactpersoon toevoegen';
$html_contact_mod = 'Contactpersoon wijzigen';
$html_contact_first = 'Voornaam';
$html_contact_last = 'Achternaam';
$html_contact_nick = 'Bijnaam';
$html_contact_mail = 'E-mailadres';
$html_contact_list = 'Contactenlijst van %1$s';
$html_contact_del = 'van de contactenlijst';
$html_contact_count = '%1$d contacten';
$html_contact_err1 = 'Het maximaal aantal contactpersonen is "%1$d"';
$html_contact_err2 = 'Er kan geen nieuw contactpersoon toegevoegd worden';
$html_contact_err3 = 'Geen toegang tot de contactenlijst';
$html_contact_none = 'Er zijn nog geen contactpersonen ingesteld.';
$html_contact_ruler_top = 'Boven';
$html_contact_listcheck_title = 'Aanvinken om e-mail aan de lijst toe te voegen.';
$html_contact_list_add = 'Aan lijst toevoegen';
$html_contact_listname = 'Lijstnaam';
$html_contact_listonly = 'Alleen lijsten';
$html_contact_all = 'Allemaal weergeven';
$html_contact_add_confirm = 'E-mail aan bestaande lijst toevoegen?';
$html_del_msg = 'Geselecteerde berichten verwijderen?';
$html_down_mail = 'Downloaden';
$original_msg = '-- Oorspronkelijk bericht --';
$to_empty = 'Het veld \'Aan\' mag niet leeg zijn!';
$html_images_warning = 'Voor uw veiligheid worden afbeeldingen niet weergegeven.';
$html_images_display = 'Afbeeldingen weergeven';
$html_smtp_error_no_conn = 'Het is niet mogelijk een SMTP-verbinding te openen';
$html_smtp_error_unexpected = 'Onverwacht SMTP-antwoord:';
$lang_could_not_connect = 'Er kan geen verbinding gemaakt worden met de server';
$lang_invalid_msg_num = 'Ongeldig berichtnummer';
$html_file_upload_attack = 'Mogelijk illegale poging om bestand te uploaden';
$html_invalid_email_address = 'Ongeldig e-mailadres';
$html_invalid_msg_per_page = 'Ongeldig aantal berichten per pagina';
$html_invalid_wrap_msg = 'Ongeldige terugloopbreedte van het bericht';
$html_seperate_msg_win = 'Berichten in nieuw venster weergeven';
$html_err_file_contacts = 'Er kan niet naar de contactenlijst geschreven worden.';
$html_session_file_error = 'Er kan niet naar het sessiebestand geschreven worden.';
$html_login_not_allowed = 'Deze gebruiker mag geen verbinding maken.';
$lang_err_send_delay = 'Tussen twee e-mails moet u minstens %1$d seconden wachten';
$html_search = 'Zoeken';
$html_new_session = 'Volgende sessie';
$html_fd_filename = '%1$s downloaden';
$html_fd_mailcount = 'Er {{PLURAL:$1|0=staan geen e-mails|1=is %1$d e-mail|staan %1$d e-mails}} in de map.';
$html_fd_mailskip = 'De volgende e-mails worden niet opgenomen in het bestand mbox, omdat ze de PHP-instelling "memory_limit" overschrijden:';
$html_fd_filesize = 'grootte %1$d';
$html_fd_skipcount = 'met %1$d e-mails';
$html_fd_largefolder = 'Afhankelijk van uw downloadsnelheid, is het mogelijk dat het downloaden te lang duurt en wordt afgebroken.<br />Controleer of uw download compleet is of steil de PHP-instelling "max_execution_time" in php.ini hoger in.';
$reset_clicked = 'Weet u zeker dat u deze dit formulieren wilt wissen?';
$html_send_recover = 'Meld u aan om het concept te herstellen!';
$html_send_discard = 'Klik hier om het klad te verwijderen.';
$html_collect_label = 'Automatisch e-mailadressen verzamelen:';
$html_collect_option0 = 'Nooit';
$html_collect_option1 = 'Alleen voor uitgaande e-mail';
$html_collect_option2 = 'Alleen voor geopende e-mail';
$html_collect_option3 = 'Altijd';
